@@ -230,7 +230,8 @@ def get_custom_fields(env):
             'value': items.get(name + '.value', '')
         }
         if field['type'] == 'select' or field['type'] == 'radio':
-            field['options'] = items.get(name + '.options', '').split('|')
+            field['options'] = map(lambda x: x.strip(),
+                                   items.get(name + '.options', '').split('|'))
         elif field['type'] == 'textarea':
             field['width'] = items.get(name + '.cols', '')
             field['height'] = items.get(name + '.rows', '')
@@ -246,7 +247,7 @@ def insert_custom_fields(env, hdf, vals = {}):
     for f in fields:
         name = f['name']
         val = vals.get('custom_' + name, f['value'])
-        pfx = 'ticket.custom.%i' % i
+        pfx = 'ticket.custom.%d' % i
         hdf.setValue('%s.name' % pfx, f['name'])
         hdf.setValue('%s.type' % pfx, f['type'])
         hdf.setValue('%s.label' % pfx, f['label'])
@@ -256,7 +257,7 @@ def insert_custom_fields(env, hdf, vals = {}):
             for option in f['options']:
                 hdf.setValue('%s.option.%d' % (pfx, j), option)
                 if val and (option == val or str(j) == val):
-                    hdf.setValue('%s.option.%i.selected' % (pfx, j), '1')
+                    hdf.setValue('%s.option.%d.selected' % (pfx, j), '1')
                 j += 1
         elif f['type'] == 'checkbox':
             if val in util.TRUE:
@@ -430,6 +431,8 @@ class TicketModule (Module):
         # List attached files
         self.env.get_attachments_hdf(self.db, 'ticket', str(id), self.req.hdf,
                                      'ticket.attachments')
+        self.req.hdf.setValue('ticket.attach_href',
+                              self.env.href.attachment('ticket', str(id), None))
 
     def render (self):
         self.perm.assert_permission (perm.TICKET_VIEW)
